# File-Breaker
<img src="https://github.com/barnabeepickle/file-breaker/blob/24bf8adf2e70805432e2d8100e058dba42c011c6/resources/logo.png?raw=True" alt="File-Breaker Logo, 3 differently colored grey squares with rounded corners and white text,the numbers 1, 2 and 3 in the center of each." width=60% height=60%>

> Written in Python using open-source tools.
## Installation
To install run
```
pip install file-breaker
```
To import into your code
```
module_name='file-breaker'
file_breaker=__import__(module_name,fromlist=['*'])
```

## About
File-Breaker is a Python library and command line tool that provides a few functions relating to dividing files into different parts.
> The Logo was created using a Python script and the Pillow Module.

> Please do not uses this in production without reviewing the [source code](https://github.com/barnabeepickle/file-breaker).

### Version System
The version of the library is determined by the commit number.
> Example: file-breaker 85 (with 85 being the number of commits in this version.)

### Environment
This project was created using VSCode Studio, vscode.dev/VSCode Web, Microsoft Dev Tunnels, Git, Github, Python 3.13, Typer and Pillow (for the logo).
> Thanks to all of the wonderful people that have worked on these projects and for their continued commitments to the open-source commmunity.

> Special thanks to the Massachusetts Institute of Technology for their open-source License.